@@ -18,7 +18,6 @@ import mock
 import pytest
 
 from google.api_core import exceptions
-from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
 import google.auth.credentials
 
@@ -276,11 +275,7 @@ def test_create_channel_implicit(grpc_secure_channel, default, composite_creds_c
 
     assert channel is grpc_secure_channel.return_value
 
-    # TODO: remove this if/else once google-auth >= 1.25.0 is required
-    if grpc_helpers._GOOGLE_AUTH_HAS_DEFAULT_SCOPES_AND_DEFAULT_HOST:
-        default.assert_called_once_with(scopes=None, default_scopes=None)
-    else:
-        default.assert_called_once_with(scopes=None)
+    default.assert_called_once_with(scopes=None, default_scopes=None)
     grpc_secure_channel.assert_called_once_with(target, composite_creds)
 
 
@@ -306,14 +301,8 @@ def test_create_channel_implicit_with_default_host(grpc_secure_channel, default,
 
     assert channel is grpc_secure_channel.return_value
 
-    # TODO: remove this if/else once google-auth >= 1.25.0 is required
-    if grpc_helpers._GOOGLE_AUTH_HAS_DEFAULT_SCOPES_AND_DEFAULT_HOST:
-        default.assert_called_once_with(scopes=None, default_scopes=None)
-        auth_metadata_plugin.assert_called_once_with(mock.sentinel.credentials, mock.sentinel.Request, default_host=default_host)
-    else:
-        default.assert_called_once_with(scopes=None)
-        auth_metadata_plugin.assert_called_once_with(mock.sentinel.credentials, mock.sentinel.Request)
-
+    default.assert_called_once_with(scopes=None, default_scopes=None)
+    auth_metadata_plugin.assert_called_once_with(mock.sentinel.credentials, mock.sentinel.Request, default_host=default_host)
     grpc_secure_channel.assert_called_once_with(target, composite_creds)
 
 
@@ -332,12 +321,7 @@ def test_create_channel_implicit_with_ssl_creds(
 
     grpc_helpers_async.create_channel(target, ssl_credentials=ssl_creds)
 
-    # TODO: remove this if/else once google-auth >= 1.25.0 is required
-    if grpc_helpers._GOOGLE_AUTH_HAS_DEFAULT_SCOPES_AND_DEFAULT_HOST:
-        default.assert_called_once_with(scopes=None, default_scopes=None)
-    else:
-        default.assert_called_once_with(scopes=None)
-
+    default.assert_called_once_with(scopes=None, default_scopes=None)
     composite_creds_call.assert_called_once_with(ssl_creds, mock.ANY)
     composite_creds = composite_creds_call.return_value
     grpc_secure_channel.assert_called_once_with(target, composite_creds)
@@ -360,12 +344,7 @@ def test_create_channel_implicit_with_scopes(
 
     assert channel is grpc_secure_channel.return_value
 
-    # TODO: remove this if/else once google-auth >= 1.25.0 is required
-    if grpc_helpers._GOOGLE_AUTH_HAS_DEFAULT_SCOPES_AND_DEFAULT_HOST:
-        default.assert_called_once_with(scopes=["one", "two"], default_scopes=None)
-    else:
-        default.assert_called_once_with(scopes=["one", "two"])
-
+    default.assert_called_once_with(scopes=["one", "two"], default_scopes=None)
     grpc_secure_channel.assert_called_once_with(target, composite_creds)
 
 
@@ -386,12 +365,7 @@ def test_create_channel_implicit_with_default_scopes(
 
     assert channel is grpc_secure_channel.return_value
 
-    # TODO: remove this if/else once google-auth >= 1.25.0 is required
-    if grpc_helpers._GOOGLE_AUTH_HAS_DEFAULT_SCOPES_AND_DEFAULT_HOST:
-        default.assert_called_once_with(scopes=None, default_scopes=["three", "four"])
-    else:
-        default.assert_called_once_with(scopes=["three", "four"])
-
+    default.assert_called_once_with(scopes=None, default_scopes=["three", "four"])
     grpc_secure_channel.assert_called_once_with(target, composite_creds)
 
 
@@ -417,12 +391,7 @@ def test_create_channel_explicit(grpc_secure_channel, auth_creds, composite_cred
 
     channel = grpc_helpers_async.create_channel(target, credentials=mock.sentinel.credentials)
 
-    # TODO: remove this if/else once google-auth >= 1.25.0 is required
-    if grpc_helpers._GOOGLE_AUTH_HAS_DEFAULT_SCOPES_AND_DEFAULT_HOST:
-        auth_creds.assert_called_once_with(mock.sentinel.credentials, scopes=None, default_scopes=None)
-    else:
-        auth_creds.assert_called_once_with(mock.sentinel.credentials, scopes=None)
-
+    auth_creds.assert_called_once_with(mock.sentinel.credentials, scopes=None, default_scopes=None)
     assert channel is grpc_secure_channel.return_value
     grpc_secure_channel.assert_called_once_with(target, composite_creds)
 
@@ -440,12 +409,8 @@ def test_create_channel_explicit_scoped(grpc_secure_channel, composite_creds_cal
     channel = grpc_helpers_async.create_channel(
         target, credentials=credentials, scopes=scopes
     )
-    # TODO: remove this if/else once google-auth >= 1.25.0 is required
-    if grpc_helpers._GOOGLE_AUTH_HAS_DEFAULT_SCOPES_AND_DEFAULT_HOST:
-        credentials.with_scopes.assert_called_once_with(scopes, default_scopes=None)
-    else:
-        credentials.with_scopes.assert_called_once_with(scopes)
 
+    credentials.with_scopes.assert_called_once_with(scopes, default_scopes=None)
     assert channel is grpc_secure_channel.return_value
     grpc_secure_channel.assert_called_once_with(target, composite_creds)
 
@@ -464,12 +429,7 @@ def test_create_channel_explicit_default_scopes(grpc_secure_channel, composite_c
         target, credentials=credentials, default_scopes=default_scopes
     )
 
-    # TODO: remove this if/else once google-auth >= 1.25.0 is required
-    if grpc_helpers._GOOGLE_AUTH_HAS_DEFAULT_SCOPES_AND_DEFAULT_HOST:
-        credentials.with_scopes.assert_called_once_with(scopes=None, default_scopes=default_scopes)
-    else:
-        credentials.with_scopes.assert_called_once_with(scopes=default_scopes)
-
+    credentials.with_scopes.assert_called_once_with(scopes=None, default_scopes=default_scopes)
     assert channel is grpc_secure_channel.return_value
     grpc_secure_channel.assert_called_once_with(target, composite_creds)
 
@@ -508,12 +468,7 @@ def test_create_channnel_with_credentials_file(load_credentials_from_file, grpc_
         target, credentials_file=credentials_file
     )
 
-    # TODO: remove this if/else once google-auth >= 1.25.0 is required
-    if grpc_helpers._GOOGLE_AUTH_HAS_DEFAULT_SCOPES_AND_DEFAULT_HOST:
-        google.auth.load_credentials_from_file.assert_called_once_with(credentials_file, scopes=None, default_scopes=None)
-    else:
-        google.auth.load_credentials_from_file.assert_called_once_with(credentials_file, scopes=None)
-
+    google.auth.load_credentials_from_file.assert_called_once_with(credentials_file, scopes=None, default_scopes=None)
     assert channel is grpc_secure_channel.return_value
     grpc_secure_channel.assert_called_once_with(target, composite_creds)
 
@@ -536,12 +491,7 @@ def test_create_channel_with_credentials_file_and_scopes(load_credentials_from_f
         target, credentials_file=credentials_file, scopes=scopes
     )
 
-    # TODO: remove this if/else once google-auth >= 1.25.0 is required
-    if grpc_helpers._GOOGLE_AUTH_HAS_DEFAULT_SCOPES_AND_DEFAULT_HOST:
-        google.auth.load_credentials_from_file.assert_called_once_with(credentials_file, scopes=scopes, default_scopes=None)
-    else:
-        google.auth.load_credentials_from_file.assert_called_once_with(credentials_file, scopes=scopes)
-
+    google.auth.load_credentials_from_file.assert_called_once_with(credentials_file, scopes=scopes, default_scopes=None)
     assert channel is grpc_secure_channel.return_value
     grpc_secure_channel.assert_called_once_with(target, composite_creds)
 
@@ -564,12 +514,7 @@ def test_create_channel_with_credentials_file_and_default_scopes(load_credential
         target, credentials_file=credentials_file, default_scopes=default_scopes
     )
 
-    # TODO: remove this if/else once google-auth >= 1.25.0 is required
-    if grpc_helpers._GOOGLE_AUTH_HAS_DEFAULT_SCOPES_AND_DEFAULT_HOST:
-        google.auth.load_credentials_from_file.assert_called_once_with(credentials_file, scopes=None, default_scopes=default_scopes)
-    else:
-        google.auth.load_credentials_from_file.assert_called_once_with(credentials_file, scopes=default_scopes)
-
+    google.auth.load_credentials_from_file.assert_called_once_with(credentials_file, scopes=None, default_scopes=default_scopes)
     assert channel is grpc_secure_channel.return_value
     grpc_secure_channel.assert_called_once_with(target, composite_creds)
 
@@ -585,12 +530,7 @@ def test_create_channel_without_grpc_gcp(grpc_secure_channel):
 
     grpc_helpers_async.create_channel(target, credentials=credentials, scopes=scopes)
     grpc_secure_channel.assert_called()
-
-    # TODO: remove this if/else once google-auth >= 1.25.0 is required
-    if grpc_helpers._GOOGLE_AUTH_HAS_DEFAULT_SCOPES_AND_DEFAULT_HOST:
-        credentials.with_scopes.assert_called_once_with(scopes, default_scopes=None)
-    else:
-        credentials.with_scopes.assert_called_once_with(scopes)
+    credentials.with_scopes.assert_called_once_with(scopes, default_scopes=None)
 
 
 @pytest.mark.asyncio
