@@ -17,19 +17,18 @@ from google.api_core.gapic_v1 import routing_header
 
 
 def test_to_routing_header():
-    params = [('name', 'meep'), ('book.read', '1')]
+    params = [("name", "meep"), ("book.read", "1")]
     value = routing_header.to_routing_header(params)
     assert value == "name=meep&book.read=1"
 
 
 def test_to_routing_header_with_slashes():
-    params = [('name', 'me/ep'), ('book.read', '1&2')]
+    params = [("name", "me/ep"), ("book.read", "1&2")]
     value = routing_header.to_routing_header(params)
     assert value == "name=me/ep&book.read=1%262"
 
 
 def test_to_grpc_metadata():
-    params = [('name', 'meep'), ('book.read', '1')]
+    params = [("name", "meep"), ("book.read", "1")]
     metadata = routing_header.to_grpc_metadata(params)
-    assert metadata == (
-        routing_header.ROUTING_METADATA_KEY, "name=meep&book.read=1")
+    assert metadata == (routing_header.ROUTING_METADATA_KEY, "name=meep&book.read=1")
